@@ -1,8 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-//
+
 //  RQuantLib -- R interface to the QuantLib libraries
 //
 //  Copyright (C) 2014         Michele Salvadore and Dirk Eddelbuettel
+//  Copyright (C) 2015 - 2018  Dirk Eddelbuettel
 //
 //  This file is part of RQuantLib.
 //
@@ -22,11 +22,11 @@
 
 //  [[Rcpp::interfaces(r, cpp)]]
 
-#include <rquantlib.h>
+#include <rquantlib_internal.h>
 
 // [[Rcpp::export]]
 Rcpp::DateVector CreateSchedule(Rcpp::List params) {
-    
+
     QuantLib::Schedule schedule = getSchedule(params);
     return Rcpp::wrap(schedule.dates());
 }
